@@ -1,3 +1,7 @@
+import ssl
+ssl._create_default_https_context = ssl._create_unverified_context
+
+
 from http.client import HTTPSConnection
 from http.client import HTTPConnection
 
@@ -31,23 +35,7 @@ def UrlParser(url):
     return protocol, domain, path
 
 
-def NetRequest(url, method = "GET", **kwargs):
-    """ -- USAGE EXAMPLE --------------------
-        >>> from netmanager import NetRequest
-        >>> url = "https://some.domain/path"
-        >>> response = NetRequest(url)
-        >>> type(response.status)
-        <class 'int'>
-
-        >>> type(response.headers)
-        <class 'dict'>
-
-        >>> type(response.result)
-        <class 'str'>
-        
-        -------------------------------------
-    """
-
+def NetRequest(url, data='', method='GET', **kwargs):
     protocol, domain, path = UrlParser(url)
     if protocol == "https":
         server = HTTPSConnection(domain)
@@ -55,7 +43,7 @@ def NetRequest(url, method = "GET", **kwargs):
     else:
         server = HTTPConnection(domain)
 
-    server.request(method, path, **kwargs)
+    server.request(method, path, data, **kwargs)
 
     response = server.getresponse()
 
